==> protector-3.1.zip: xoops_trust_path/modules/protector/language/japanese/admin.php <==
<?php

// mymenu
define('_MD_A_MYMENU_MYTPLSADMIN','');
define('_MD_A_MYMENU_MYBLOCKSADMIN','');
define('_MD_A_MYMENU_MYPREFERENCES','');

// index.php
define("_AM_TH_DATETIME","");
define("_AM_TH_USER","桼");
define("_AM_TH_IP","IP");
define("_AM_TH_AGENT","AGENT");
define("_AM_TH_TYPE","");
define("_AM_TH_DESCRIPTION","ܺ");

define( "_AM_TH_BADIPS" , 'IPꥹ<br /><br /><span style="font-weight:normal;">ԣIPɥ쥹ǵҤƤסˡʤġ</span>' ) ;

define( "_AM_TH_GROUP1IPS" , 'ԥ롼(1)εIP<br /><br /><span style="font-weight:normal;">ԣIPɥ쥹ǵҤƤסˡ<br />192.168. ȤС192.168.*ΤߴԤˤʤޤʤġ</span>' ) ;

define( "_AM_LABEL_COMPACTLOG" , "򥳥ѥȲ" ) ;
define( "_AM_BUTTON_COMPACTLOG" , "ѥȲ¹" ) ;
define( "_AM_JS_COMPACTLOGCONFIRM" , "IPȼ̤νʣ쥳ɤޤ" ) ;
define( "_AM_LABEL_REMOVEALL" , "쥳ɤ:" ) ;
define( "_AM_BUTTON_REMOVEALL" , "¹" ) ;
define( "_AM_JS_REMOVEALLCONFIRM" , "̵ǺޤˤǤ" ) ;
define( "_AM_LABEL_REMOVE" , "å쥳ɤ:" ) ;
define( "_AM_BUTTON_REMOVE" , "¹" ) ;
define( "_AM_JS_REMOVECONFIRM" , "˺ƤǤ" ) ;
define( "_AM_MSG_IPFILESUPDATED" , "IPꥹȥե񤭴ޤ" ) ;
define( "_AM_MSG_BADIPSCANTOPEN" , "IPꥹȥե뤬ޤ" ) ;
define( "_AM_MSG_GROUP1IPSCANTOPEN" , "IPꥹȥե뤬ޤ" ) ;
define( "_AM_MSG_REMOVED" , "ޤ" ) ;
define( "_AM_FMT_CONFIGSNOTWRITABLE" , "configsǥ쥯ȥ꤬ĤƤޤ: %s" ) ;


// prefix_manager.php
define( "_AM_H3_PREFIXMAN" , "PREFIX ޥ͡" ) ;
define( "_AM_MSG_DBUPDATED" , "ǡ١ޤ" ) ;
define( "_AM_CONFIRM_DELETE" , "ơ֥뤬ޤǤ?" ) ;
define( "_AM_TXT_HOWTOCHANGEDB" , "prefixѹϡ%s/mainfile.php ΰʲʬ񤭴Ƥ<br /><br />define('XOOPS_DB_PREFIX', '<b>%s</b>');" ) ;


// advisory.php
define("_AM_ADV_NOTSECURE","侩");

define("_AM_ADV_REGISTERGLOBALS","ϡ͡ѿ򾷤ޤ<br />⤷.htaccess֤륵ФǤСXOOPS󥹥ȡǥ쥯ȥ.htaccess뤫Խ뤫Ʋ");
define("_AM_ADV_ALLOWURLFOPEN","ȡǤդΥץȤ¹Ԥޤ<br />ѹˤϥФδԸ¤ɬפǤ<br />ȤǴƤ륵ФǤСphp.inihttpd.confԽƲ<br />ǤʤϡдԤˤꤤƤߤƲ");
define("_AM_ADV_USETRANSSID","åIDưŪ˥󥯤ɽȤʤäƤޤ<br />åϥåɤˤ⡢XOOPS󥹥ȡǥ쥯ȥ.htaccess뤫Խ뤫Ʋ<br /><b>php_flag session.use_trans_sid off</b>");
define("_AM_ADV_DBPREFIX","DBƬǥեȤxoopsΤޤޤʤΤǡSQL Injection˼夤֤Ǥ<br />ָΩȤ̵פʤɡSQL InjectionкONˤ뤳Ȥ˺ʤ");
define("_AM_ADV_LINK_TO_PREFIXMAN","PREFIXޥ͡");
define("_AM_ADV_MAINUNPATCHED","README˵Ҥ줿̤ˡmainfile.php ˥ѥåƤƲ");

define("_AM_ADV_SUBTITLECHECK","Protectorưå");
define("_AM_ADV_CHECKCONTAMI","ѿ");
define("_AM_ADV_CHECKISOCOM","Ω");


?>

==> protector-3.2.zip: xoops_trust_path/modules/protector/language/japanese/admin.php <==
<?php

// mymenu
define('_MD_A_MYMENU_MYTPLSADMIN','');
define('_MD_A_MYMENU_MYBLOCKSADMIN','');
define('_MD_A_MYMENU_MYPREFERENCES','');

// index.php
define("_AM_TH_DATETIME","");
define("_AM_TH_USER","桼");
define("_AM_TH_IP","IP");
define("_AM_TH_AGENT","AGENT");
define("_AM_TH_TYPE","");
define("_AM_TH_DESCRIPTION","ܺ");

define( "_AM_TH_BADIPS" , 'IPꥹ<br /><br /><span style="font-weight:normal;">ԣIPɥ쥹ǵҤƤסˡʤġ</span>' ) ;

define( "_AM_TH_GROUP1IPS" , 'ԥ롼(1)εIP<br /><br /><span style="font-weight:normal;">ԣIPɥ쥹ǵҤƤסˡ<br />192.168. ȤС192.168.*ΤߴԤˤʤޤʤġ</span>' ) ;

define( "_AM_LABEL_COMPACTLOG" , "򥳥ѥȲ" ) ;
define( "_AM_BUTTON_COMPACTLOG" , "ѥȲ¹" ) ;
define( "_AM_JS_COMPACTLOGCONFIRM" , "IPȼ̤νʣ쥳ɤޤ" ) ;
define( "_AM_LABEL_REMOVEALL" , "쥳ɤ:" ) ;
define( "_AM_BUTTON_REMOVEALL" , "¹" ) ;
define( "_AM_JS_REMOVEALLCONFIRM" , "̵ǺޤˤǤ" ) ;
define( "_AM_LABEL_REMOVE" , "å쥳ɤ:" ) ;
define( "_AM_BUTTON_REMOVE" , "¹" ) ;
define( "_AM_JS_REMOVECONFIRM" , "˺ƤǤ" ) ;
define( "_AM_MSG_IPFILESUPDATED" , "IPꥹȥե񤭴ޤ" ) ;
define( "_AM_MSG_BADIPSCANTOPEN" , "IPꥹȥե뤬ޤ" ) ;
define( "_AM_MSG_GROUP1IPSCANTOPEN" , "IPꥹȥե뤬ޤ" ) ;
define( "_AM_MSG_REMOVED" , "ޤ" ) ;
define( "_AM_FMT_CONFIGSNOTWRITABLE" , "configsǥ쥯ȥ꤬ĤƤޤ: %s" ) ;


// prefix_manager.php
define( "_AM_H3_PREFIXMAN" , "PREFIX ޥ͡" ) ;
define( "_AM_MSG_DBUPDATED" , "ǡ١ޤ" ) ;
define( "_AM_CONFIRM_DELETE" , "ơ֥뤬ޤǤ?" ) ;
define( "_AM_TXT_HOWTOCHANGEDB" , "prefixѹϡ%s/mainfile.php ΰʲʬ񤭴Ƥ<br /><br />define('XOOPS_DB_PREFIX', '<b>%s</b>');" ) ;


// advisory.php
define("_AM_ADV_NOTSECURE","侩");

define("_AM_ADV_TRUSTPATHPUBLIC","NGȤɽƤꡢǥ顼Фʤ褦ʤXOOPS_TRUST_PATHˡ꤬ޤXOOPS_TRUST_PATHDocumentRoot֤ΤܤǤǤʤǤXOOPS_TRUST_PATHľDENY FROM ALLΰԤ.htaccessɲäʤɤơXOOPS_TRUST_PATHľܥǤʤ褦ˤɬפޤ");
define("_AM_ADV_TRUSTPATHPUBLICLINK","TRUST_PATHPHPեľǤʤȤγǧʥ褬404,403,500顼ʤ");
define("_AM_ADV_REGISTERGLOBALS","ϡ͡ѿ򾷤ޤ<br />⤷.htaccess֤륵ФǤСXOOPS󥹥ȡǥ쥯ȥ.htaccess뤫Խ뤫Ʋ");
define("_AM_ADV_ALLOWURLFOPEN","ȡǤդΥץȤ¹Ԥޤ<br />ѹˤϥФδԸ¤ɬפǤ<br />ȤǴƤ륵ФǤСphp.inihttpd.confԽƲ<br />ǤʤϡдԤˤꤤƤߤƲ");
define("_AM_ADV_USETRANSSID","åIDưŪ˥󥯤ɽȤʤäƤޤ<br />åϥåɤˤ⡢XOOPS󥹥ȡǥ쥯ȥ.htaccess뤫Խ뤫Ʋ<br /><b>php_flag session.use_trans_sid off</b>");
define("_AM_ADV_DBPREFIX","DBƬǥեȤxoopsΤޤޤʤΤǡSQL Injection˼夤֤Ǥ<br />ָΩȤ̵פʤɡSQL InjectionкONˤ뤳Ȥ˺ʤ");
define("_AM_ADV_LINK_TO_PREFIXMAN","PREFIXޥ͡");
define("_AM_ADV_MAINUNPATCHED","README˵Ҥ줿̤ˡmainfile.php ˥ѥåƤƲ");

define("_AM_ADV_SUBTITLECHECK","Protectorưå");
define("_AM_ADV_CHECKCONTAMI","ѿ");
define("_AM_ADV_CHECKISOCOM","Ω");


?>
